
/****************************************************************************/
/*  Copyright (c) 1995-1999, ADLink Technology Inc.  All rights reserved.   */
/*                                                                          */
/*  File Name   :   Example.c                                               */
/*  Purpose     :   Sample program of PCI-8134 card on DOS environment      */
/*  Date        :   12/31/1999                                              */
/*  Revision    :   1.00                                                    */
/*  Programmer  :   Yi_Tun Huang                                            */
/****************************************************************************/

#include <dos.h>
#include <conio.h>
#include <bios.h>
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include "pci_8134.h"

PCI_INFO info;

#define         axis_no         0
#define         cno             0

#define         PEL_INT         0x01
#define         NEL_INT         0x02
#define         ALM_INT         0x10
#define         MOVE_INT        0x0800
#define         HOME_INT        0x0200

int function_test( void );
U16     int_flag = 0, irq_axs;
U32     irq_sts;

/****************************************************************************/
/*      MAIN for Example.c                                                  */
/****************************************************************************/
void main( void )
{
        U16     i, bn=0;

//---------------------------------------------------------------------
//      Initialization of PCI-8134 card
//---------------------------------------------------------------------
        _8134_Initial( &bn,  &info  );

        for( i =0; i<bn; i++ )
        {
            printf("==================================================\n" );
            printf("Base address of PCI-8134 card[%1d]: %lX\n" ,i, info.baseAddr[i] );
            printf("IRQ Channel  of PCI-8134 card[%1d]: %d\n"  ,i, info.irqNo[i]    );
	    printf("==================================================\n" );
        }
//---------------------------------------------------------------------
//      Initial Configuration for Axis 0
//---------------------------------------------------------------------
        _8134_Set_SVON(axis_no, 1);
        set_alm_logic(axis_no, 0, 0);   // ALARM mode configure
        set_pls_outmode(axis_no, 0);    // Set Pulse output mode to OUT/DIR
        set_cnt_src(axis_no, 0);        // EA & EB input Count
        set_pls_iptmode(axis_no, 2);    // EA & EB is 4x AB phase pulse input
        set_move_ratio(axis_no, 2.5);
                        // Resolution of feedback is 2.5 times of command Pulse
        set_home_config(axis_no, 2, 1, 1, 0);
                        // Home mode configure
//---------------------------------------------------------------------
//      Subroutine for Function test
//---------------------------------------------------------------------
        function_test( );
//---------------------------------------------------------------------
//      Close all resource used by PCI-8134
//---------------------------------------------------------------------
        for(i=0; i<bn; i++)
          _8134_Close(i);

}

/****************************************************************************/
/*      Subroutine for PCI-8134 Function Test                               */
/****************************************************************************/
int function_test( void )
{
        U16     err=0;
        U16     io_tmp;
        U8      key;
        F64     pos;

//---------------------------------------------------------------------
//      Set Int Configuration
//---------------------------------------------------------------------
                // Set Interrupt Factor for Axis 0
         set_int_factor(axis_no, 0x65);         // +-EL, ALM, Home, Move
                // Enable Interrupt for card 0
         _8134_Set_INT_Enable( cno, 1);         // Enable Int

//---------------------------------------------------------------------
//      Loop for Handling Command and show Interrupt status
//---------------------------------------------------------------------
        printf(" Command for Function Test:\n");
        printf("   (1). Press 'f' key to move forward.\n");
        printf("   (2). Press 'b' key to move backward.\n");
        printf("   (3). Press 'h' key to return home.\n");
        printf("   (3). Press 'e' to end function test.\n");
        printf("==================================================\n" );
        do
        {
           while(int_flag)
            {
             int_flag = 0;
             printf(" IRQ STATUS of Axis %x is: 0x%lx\n", irq_axs, irq_sts);
             get_io_status(axis_no, &io_tmp);
             printf(" iiiooo > io_status is :0x%x\n", io_tmp);
//
             if( irq_sts & PEL_INT)
               printf(" --->> INT axis %d is caused by Pos. Limit Switch\n", irq_axs);
             else if( irq_sts & NEL_INT)
               printf(" --->> INT axis %d is caused by Neg. Limit Switch\n", irq_axs);
             else if( irq_sts & ALM_INT)
               printf(" --->> INT axis %d is caused by ALARM signal\n", irq_axs);
             else if( irq_sts & HOME_INT)
               printf(" --->> INT axis %d is caused by Home Coming!\n", irq_axs);
             else if( irq_sts & MOVE_INT)
             {
               get_position(axis_no, &pos);
               printf(" --->> INT axis %d is caused by Move Finish!\n", irq_axs);
               printf("...... Current Position is: %f\n", pos);
             }
            }
//
           if(kbhit())
             {
              key = getch();
              if((key == 'f') || (key=='F'))
                 start_rs_move(axis_no, 80000.0, 100.0, 100000.0, 0.1, 0.1 );
              else if((key == 'b') || (key=='B'))
                 start_rs_move(axis_no, -80000.0, 100.0, 100000.0, 0.1, 0.3);
              else if((key == '1'))
                  v_change(axis_no, 25000.0, 0.01);
              else if((key == '2'))
                  v_change(axis_no, 50000.0, 0.01);
              else if((key == '3'))
                  v_change(axis_no, 150000.0, 0.01);
              else if((key == 's') || (key=='S'))
                   v_stop(axis_no, 0.5);
              else if((key == 'h') || (key=='H'))
                      home_move(axis_no, -10000.0, -100000.0, 0.2);
             }
//
        }while( (key != 'e') && (key != 'E'));
//---------------------------------------------------------------------
        return err ;
}

/****************************************************************************/
/*      Interrupt Service Routines (ISR)                                    */
/****************************************************************************/
void interrupt _8134_isr0(void)
{
        U16     int_axis;
        U16     irq_status;
//
        disable();
        _8134_Get_IRQ_Status(0, &irq_status);
        if(irq_status)
         {
          get_int_axis(&int_axis);
          int_flag = 1;
          irq_axs = int_axis;
          get_int_status(int_axis, &irq_sts);
         }
        else
           _chain_intr(pcinfo.old_isr[0]);
//
        outportb(0x20, 0x20);
        outportb(0xA0, 0x20);
//---------------------------------------------------------------------
        enable();

}

void interrupt _8134_isr1(void)
{
        U16     int_axis;
        U16     irq_status;
//
        disable();
        _8134_Get_IRQ_Status(1, &irq_status);
        if(irq_status)
         {
          get_int_axis(&int_axis);
          int_flag = 1;
          irq_axs = int_axis;
          get_int_status(int_axis, &irq_sts);
         }
        else
           _chain_intr(pcinfo.old_isr[1]);
//
        outportb(0x20, 0x20);
        outportb(0xA0, 0x20);
//---------------------------------------------------------------------
        enable();

}
void interrupt _8134_isr2(void)
{
        U16     int_axis;
        U16     irq_status;
//
        disable();
        _8134_Get_IRQ_Status(2, &irq_status);
        if(irq_status)
         {
          get_int_axis(&int_axis);
          int_flag = 1;
          irq_axs = int_axis;
          get_int_status(int_axis, &irq_sts);
         }
        else
           _chain_intr(pcinfo.old_isr[2]);
//
        outportb(0x20, 0x20);
        outportb(0xA0, 0x20);
//---------------------------------------------------------------------
        enable();

}
void interrupt _8134_isr3(void){}
void interrupt _8134_isr4(void){}
void interrupt _8134_isr5(void){}
void interrupt _8134_isr6(void){}
void interrupt _8134_isr7(void){}
void interrupt _8134_isr8(void){}
void interrupt _8134_isr9(void){}
void interrupt _8134_isra(void){}
void interrupt _8134_isrb(void){}

